@@ -76,7 +76,8 @@ class Compiler:
     # Generate chain command
     def chain_generator(self, parms):
         assignment = parms["match"].group(1) if parms["match"].group(1) else ""
-        cmd = f'"{parms["match"].group(2)}"' if parms["match"].group(2)[0] != "$" else parms["match"].group(2).replace("$", "")
+        quote_type = "'" if "'" not in parms["match"].group(2) else '"'
+        cmd = f'{quote_type}{parms["match"].group(2)}{quote_type}' if parms["match"].group(2)[0] != "$" else parms["match"].group(2).replace("$", "")
         args = parms["match"].group(3)
 
         self.output.append(f'{assignment}_watiba_.chain({cmd}, {args})')
